@@ -9,11 +9,11 @@ from typing import overload
 import pipe21 as P
 
 from musictool import config
+from musictool.config import RED
 from musictool.note import AnyNote
 from musictool.note import Note
 from musictool.note import SpecificNote
 from musictool.note import str_to_note
-from musictool.piano import Piano
 from musictool.util import typeguards
 from musictool.util.cache import Cached
 
@@ -188,9 +188,6 @@ class NoteSet(Cached):
             _ += f'/{self.root.name}'
         return _
 
-    def to_piano_image(self):
-        return Piano(notes=self.notes)._repr_svg_()
-
     def with_html_classes(self, classes: tuple[str, ...]) -> str:
         prev = self.html_classes
         self.html_classes = prev + classes
@@ -198,12 +195,14 @@ class NoteSet(Cached):
         self.html_classes = prev
         return r
 
+    def to_piano_image(self) -> str:
+        from musictool.piano import Piano  # hack to fix circular import
+        return Piano(note_colors={note: RED for note in self})._repr_svg_()
+
     def _repr_html_(self) -> str:
-        notes_str = ''.join(note.name for note in self)
-        root_str = f'/{self.root.name}' if self.root is not None else ''
         return f"""
         <div class='{' '.join(self.html_classes)}'>
-        <span class='card_header'><h3>{notes_str}{root_str}</h3></span>
+        <h3 style='height:1em;' class='card_header'>{self!r}</h3>
         {self.to_piano_image()}
         </div>
         """
